<?php

defined('_JEXEC') or die('Restricted access');

class CrossfitModelUsers extends JModelList {

    public function __construct($config = array()) {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'idUser',
                'nome',
                'cognome',
                'email',
                'codiceFiscale',
                'dataNascita',
                'citta',
                'dataScadenzaIscrizione',
                'dataScadenzaAbbonamento',
                'dataScadenzaCertificato',
                'idSubscription',
                'idPalestra',
                'published',
                'statoIscrizioni',
                'statoCertificato',
                'statoAbbonamento',
                'customFilter'
            );
        }

        parent::__construct($config);
    }

    protected function getListQuery() {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        $query->select("*")
                ->from("#__crossfit_users CU")
                ->innerJoin("#__users U ON U.id = CU.idUserJoomla");

        $search = $this->getState('filter.search');
        if (!empty($search)) {
            $like = $db->quote('%' . $search . '%');
            $query->where('CONCAT(nome, " ", cognome, " ", idUser, " ", citta, " ", codiceFiscale, " ", U.email) LIKE ' . $like);
        }

        $statoUtente = $this->getState('filter.statoUtente');
        switch ($statoUtente) {
            case 1:
            default:
                $query->where('published = 1');
                break;
            case 2:
                $query->where('published = 0');
                break;
            case 3:
                $query->where('published = 1')
                        ->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE dataInizio <= NOW() AND dataScadenzaAbbonamento >= NOW())')
                        ->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_iscrizioni WHERE dataScadenza >= NOW())')
                        ->where('DATE_ADD(dataCertificato, INTERVAL 1 YEAR) > CURRENT_DATE')
                        ->where('idUserJoomla NOT IN (SELECT idu FROM `#__rseventspro_users` WHERE date >= DATE_SUB(NOW(), INTERVAL 14 DAY))');
                break;
        }

        $idSubscription = $this->getState('filter.idSubscription');
        $statoAbbonamento = $this->getState('filter.statoAbbonamento');
        if (is_numeric($statoAbbonamento) && !$idSubscription) {
            switch ($statoAbbonamento) {
                case 1:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE NOW() BETWEEN dataInizio AND dataScadenzaAbbonamento AND sospeso = 0)');
                    break;
                case 2:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE dataScadenzaAbbonamento < NOW() AND sospeso = 0)');
                    $query->where('CU.idUser NOT IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE NOW() BETWEEN dataInizio AND dataScadenzaAbbonamento)');
                    break;
                case 3:
                    $query->where('CU.idUser NOT IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti)');
                    break;
                case 4:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE NOW() BETWEEN dataInizio AND dataScadenzaAbbonamento AND sospeso = 1)');
                    break;
                case 5:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE dataScadenzaAbbonamento BETWEEN DATE_ADD(CURRENT_DATE, INTERVAL 1 DAY) AND DATE_ADD(CURRENT_DATE, INTERVAL 7 DAY))');
                    break;
                case 6:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE dataScadenzaAbbonamento BETWEEN DATE_ADD(CURRENT_DATE, INTERVAL 8 DAY) AND DATE_ADD(CURRENT_DATE, INTERVAL 15 DAY))');
                    break;
                case 7:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE dataScadenzaAbbonamento BETWEEN DATE_ADD(CURRENT_DATE, INTERVAL 16 DAY) AND DATE_ADD(CURRENT_DATE, INTERVAL 30 DAY))');
                    break;
            }
        } else if (($statoAbbonamento) && ($idSubscription)) {
            if (strpos($idSubscription, "MTH-") !== false) {
                $mesi = str_replace("MTH-", "", $idSubscription);
                if ($mesi) {
                    $query->where('mesi = ' . (int) $mesi);
                }
            } elseif ($idSubscription == "CUSTOM-01") {
                $query->where('adIngressiTotali = 1');
            } else {
                $where = ('idSubscription = ' . (int) $idSubscription);
            }

            switch ($statoAbbonamento) {
                case 1:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE NOW() BETWEEN dataInizio AND dataScadenzaAbbonamento AND sospeso = 0 AND ' . $where . ')');
                    break;
                case 2:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE dataScadenzaAbbonamento < NOW() AND sospeso = 0 AND ' . $where . ')');
                    $query->where('CU.idUser NOT IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE NOW() BETWEEN dataInizio AND dataScadenzaAbbonamento)');
                    break;
                case 3:
                    $query->where('CU.idUser NOT IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti AND ' . $where . ')');
                    break;
                case 4:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE NOW() BETWEEN dataInizio AND dataScadenzaAbbonamento AND sospeso = 1 AND ' . $where . ')');
                    break;
                case 5:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE dataScadenzaAbbonamento BETWEEN DATE_ADD(CURRENT_DATE, INTERVAL 1 DAY) AND DATE_ADD(CURRENT_DATE, INTERVAL 7 DAY) AND ' . $where . ')');
                    break;
                case 6:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE dataScadenzaAbbonamento BETWEEN DATE_ADD(CURRENT_DATE, INTERVAL 8 DAY) AND DATE_ADD(CURRENT_DATE, INTERVAL 15 DAY) AND ' . $where . ')');
                    break;
                case 7:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_abbonamenti WHERE dataScadenzaAbbonamento BETWEEN DATE_ADD(CURRENT_DATE, INTERVAL 16 DAY) AND DATE_ADD(CURRENT_DATE, INTERVAL 30 DAY) AND ' . $where . ')');
                    break;
            }
        }

        $statoCertificato = $this->getState('filter.statoCertificato');
        if (is_numeric($statoCertificato)) {
            switch ($statoCertificato) {
                case 1:
                    $query->where('DATE_ADD(dataCertificato, INTERVAL 1 YEAR) >= NOW()');
                    break;
                case 2:
                    $query->where('DATE_ADD(dataCertificato, INTERVAL 1 YEAR) < NOW()');
                    break;
                case 3:
                    $query->where("(dataCertificato IS NULL OR dataCertificato = '0000-00-00')");
                    break;
                case 4:
                    $query->where('(DATE_ADD(dataCertificato, INTERVAL 1 YEAR) BETWEEN DATE_ADD(NOW(), INTERVAL 0 DAY) AND DATE_ADD(NOW(), INTERVAL 7 DAY))');
                    break;
                case 5:
                    $query->where('(DATE_ADD(dataCertificato, INTERVAL 1 YEAR) BETWEEN DATE_ADD(NOW(), INTERVAL 7 DAY) AND DATE_ADD(NOW(), INTERVAL 15 DAY))');
                    break;
            }
        }

        $statoIscrizioni = $this->getState('filter.statoIscrizioni');
        if (is_numeric($statoIscrizioni)) {
            switch ($statoIscrizioni) {
                case 1:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_iscrizioni WHERE dataScadenza > NOW())');
                    break;
                case 2:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_iscrizioni WHERE dataScadenza <= NOW())');
                    break;
                case 3:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_iscrizioni WHERE pagato = 0)');
                    break;
                case 4:
                    $query->where('CU.idUser NOT IN (SELECT idUser FROM #__crossfit_v_scadenze_iscrizioni)');
                    break;
                case 5:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_iscrizioni WHERE dataScadenza BETWEEN NOW() AND DATE_ADD(NOW(), INTERVAL 7 DAY))');
                    break;
                case 6:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_iscrizioni WHERE dataScadenza BETWEEN NOW() AND DATE_ADD(NOW(), INTERVAL 15 DAY))');
                    break;
                case 7:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_iscrizioni WHERE dataInizio BETWEEN DATE_SUB(NOW(), INTERVAL 15 DAY) AND NOW())');
                    break;
                case 8:
                    $query->where('CU.idUser IN (SELECT idUser FROM #__crossfit_v_scadenze_iscrizioni WHERE dataInizio BETWEEN DATE_SUB(NOW(), INTERVAL 7 DAY) AND NOW())');
                    break;
            }
        }

        if ($subscriptionstardate = $this->getState('filter.subscriptionstartdate')) {
            $query->where("CU.idUser IN (SELECT idUser FROM #__crossfit_subscriptions_users WHERE dataInizio BETWEEN '{$subscriptionstardate}-01' AND '{$subscriptionstardate}-31')");
        }

        if ($membershipstartdate = $this->getState('filter.membershipstartdate')) {
            $query->where("CU.idUser IN (SELECT idUser FROM #__crossfit_memberships WHERE dataInizio BETWEEN '{$membershipstartdate}-01' AND '{$membershipstartdate}-31')");
        }

        $idPalestra = $this->getState('filter.idPalestra');
        if (!$idPalestra && CrossfitHelper::isConsultazione()) {
            $palestreConsultazione = CrossfitHelper::getPalestreConsultazione();
            if ($palestreConsultazione) {
                foreach ($palestreConsultazione as $palestra) {
                    $ids[] = $palestra->id;
                }
                $query->where("idPalestra IN (" . implode(", ", $ids) . ")");
            }
        } elseif ($idPalestra) {
            $query->where("idPalestra = {$idPalestra}");
        }

        $orderCol = $this->state->get('list.ordering', 'nome');
        $orderDirn = $this->state->get('list.direction', 'asc');
        $query->order($db->escape($orderCol) . ' ' . $db->escape($orderDirn));

        //die("<pre>" . $query->__toString());

        return $query;
    }

    public function publish($published = 1) {
        $cid = JRequest::getVar('cid');
        $mainframe = JFactory::getApplication();
        $db = JFactory::getDbo();
        foreach ($cid as $id) {
            $data = new stdClass;
            $data->idUser = $id;
            $data->published = $published;
            $db->updateObject('#__crossfit_users', $data, 'idUser');
        }

        $mainframe->redirect('index.php?option=com_crossfit&view=users');
    }

    public function unpublish() {
        $this->publish(0);
    }

    public function delete($id = null) {
        if (!$id) {
            return;
        }

        $db = JFactory::getDbo();
        $query = $db->getQuery(true);

        $query->select("idUserJoomla")->from('#__crossfit_users')->where('idUser = ' . $query->quote($id));
        $db->setQuery($query);

        $idUserJoomla = $db->loadResult();
        $user = JFactory::getUser($idUserJoomla);

        if ($user->delete()) {
            $query->clear();
            $query->delete('#__crossfit_users')->where('idUser = ' . $query->quote($id));
            $db->setQuery($query);
            return $db->execute();
        }

        return false;
    }

    public function export() {
        $cid = JRequest::getVar('cid');
        if (!$cid)
            return false;

        require_once JPATH_COMPONENT_ADMINISTRATOR . '/lib/PHPExcel.php';
        require_once JPATH_COMPONENT_ADMINISTRATOR . '/lib/PHPExcel/Writer/Excel2007.php';

        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query->select("*")
                ->from("#__crossfit_users")
                ->where("idUser IN (" . implode(",", $cid) . ")")
                ->order("nome, cognome");

        $db->setQuery($query);
        date_default_timezone_set('Europe/Rome');

        if ($results = $db->loadObjectList()) {

            $objPHPExcel = new PHPExcel();

            $objPHPExcel->getProperties()
                    ->setCreator("Swype Lab")
                    ->setLastModifiedBy("Swype Lab")
                    ->setTitle("Esportazione utenti box")
                    ->setSubject("Esportazione utenti box")
                    ->setDescription("Esportazione utenti box");

            $objPHPExcel->getDefaultStyle()->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_LEFT);

            $objPHPExcel->setActiveSheetIndex(0)
                    ->setCellValue('A1', 'ID utente')
                    ->setCellValue('B1', 'Nome')
                    ->setCellValue('C1', 'Cognome')
                    ->setCellValue('D1', 'EMail')
                    ->setCellValue('E1', 'Codice Fiscale')
                    ->setCellValue('F1', 'Telefono')
                    ->setCellValue('G1', 'Data di nascita')
                    ->setCellValue('H1', 'Città di nascita')
                    ->setCellValue('I1', 'Indirizzo')
                    ->setCellValue('J1', 'Scadenza certificato medico')
                    ->setCellValue('K1', 'Scadenza iscrizione')
                    ->setCellValue('L1', 'Iscrizione pagata')
                    ->setCellValue('M1', 'Tipologia abbonamento')
                    ->setCellValue('N1', 'Prezzo')
                    ->setCellValue('O1', 'Pagato')
                    ->setCellValue('P1', 'Giorni aggiuntivi')
                    ->setCellValue('Q1', 'Data inizio')
                    ->setCellValue('R1', 'Data scadenza')
                    ->setCellValue('S1', 'Giorni di sospensione')
                    ->setCellValue('T1', 'Nuova data di scadenza')
                    ->getStyle('A1:T1');

            $i = 2;
            foreach ($results as $v) {

                $query->clear()
                        ->select("dataInizio, DATE_ADD(dataInizio, INTERVAL durata YEAR) as dataScadenza, pagato, costo")
                        ->from("#__crossfit_memberships")
                        ->where("idUser = {$v->idUser}")
                        ->order("DATE_ADD(dataInizio, INTERVAL durata YEAR) DESC")
                        ->limit("0,1");

                $db->setQuery($query);
                $membership = $db->loadObject();

                $query->clear()
                        ->select("u.*,
                                DATE_ADD(DATE_ADD(dataInizio, INTERVAL s.mesi MONTH), INTERVAL giorniAggiuntivi DAY) as dataScadenza,
                                DATE_ADD(DATE_ADD(DATE_ADD(dataInizio, INTERVAL s.mesi MONTH), INTERVAL giorniAggiuntivi DAY), INTERVAL giorniSospensione DAY) as dataScadenzaSospensione,
                                s.nome")
                        ->from("#__crossfit_subscriptions_users as u")
                        ->innerJoin("#__crossfit_subscriptions as s ON u.idSubscription = s.idSubscription")
                        ->where("idUser = {$v->idUser}")
                        ->order("DATE_ADD(DATE_ADD(dataInizio, INTERVAL s.mesi MONTH), INTERVAL giorniAggiuntivi DAY) DESC")
                        ->limit("0,1");

                $db->setQuery($query);
                $subscription = $db->loadObject();

                $objPHPExcel->getActiveSheet()
                        ->setCellValue('A' . $i, $v->idUser)
                        ->setCellValue('B' . $i, $v->nome)
                        ->setCellValue('C' . $i, $v->cognome)
                        ->setCellValue('D' . $i, $v->email)
                        ->setCellValue('E' . $i, $v->codiceFiscale)
                        ->setCellValue('F' . $i, $v->telefono)
                        ->setCellValue('G' . $i, ($v->dataNascita ? date("d/m/Y", strtotime($v->dataNascita)) : ""))
                        ->setCellValue('H' . $i, $v->cittaNascita)
                        ->setCellValue('I' . $i, ($v->indirizzo ? $v->indirizzo . ", " . $v->citta : $v->citta))
                        ->setCellValue('J' . $i, ($v->dataCertificato ? date("d/m/Y", strtotime($v->dataCertificato)) : ""));

                if ($membership) {
                    $objPHPExcel->getActiveSheet()
                            ->setCellValue('K' . $i, date("d/m/Y", strtotime($membership->dataScadenza)))
                            ->setCellValue('L' . $i, "Pagato: " . number_format($membership->costo, 2, ",", ".") . " €");
                }

                if ($subscription) {
                    $objPHPExcel->getActiveSheet()
                            ->setCellValue('M' . $i, $subscription->nome)
                            ->setCellValue('N' . $i, number_format($subscription->prezzo, 2, ",", ".") . " €")
                            ->setCellValue('O' . $i, number_format($subscription->pagato, 2, ",", ".") . " €")
                            ->setCellValue('P' . $i, $subscription->giorniAggiuntivi)
                            ->setCellValue('Q' . $i, date("d/m/Y", strtotime($subscription->dataInizio)))
                            ->setCellValue('R' . $i, date("d/m/Y", strtotime($subscription->dataScadenza)));

                    if ($subscription->sospeso) {
                        $objPHPExcel->getActiveSheet()
                                ->setCellValue('S' . $i, $subscription->giorniSospensione)
                                ->setCellValue('T' . $i, date("d/m/Y", strtotime($subscription->dataScadenzaSospensione)));
                    }
                }

                $i++;
            }
            for ($col = 'A'; $col !== 'U'; $col++) {
                $objPHPExcel->getActiveSheet()->getColumnDimension($col)->setAutoSize(true);
            }

            $objPHPExcel->getActiveSheet()->setTitle('Export utenti BOX');
            $objPHPExcel->setActiveSheetIndex(0);
            header('Content-Type: application/vnd.ms-excel');
            header('Content-Disposition: attachment;filename="export-utenti-box-(' . date("d-m-Y H:i:s") . ').xls"');
            header('Cache-Control: max-age=1');

            header('Expires: Mon, 26 Jul 1997 05:00:00 GMT');
            header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
            header('Cache-Control: cache, must-revalidate');
            header('Pragma: public');

            $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel5');
            $objWriter->save('php://output');
        }
        JFactory::getApplication()->close();
    }

    public function resendEmail() {
        $cid = JRequest::getVar('cid');
        if (!$cid) {
            return false;
        }
        $db = JFactory::getDbo();

        $j = 0;

        foreach ($cid as $id) {
            $query = $db->getQuery(true);

            $query->select("idUserJoomla")->from("#__crossfit_users")->where("idUser = {$id}");
            $db->setQuery($query);
            $id = $db->loadResult();
            $usr = JFactory::getUser($id);

            $username = $usr->username;
            $email = $usr->email;

            $randpass = $username;

            $salt = JUserHelper::genRandomPassword(32);
            $crypt = JUserHelper::getCryptedPassword($randpass, $salt);
            $password = "$crypt:$salt";

            $object = new stdClass();

            // Must be a valid primary key value.
            $object->id = $id;
            $object->password = $password;
            $object->requireReset = 1; //imposto la richiesta di cambio psw al primo accesso
            $result = $db->updateObject('#__users', $object, 'id');
            if ($result !== true) {
                echo 'Error to saving data for user: ' . $username . ' id:' . $id;
            } else {
                echo 'Data saved for user: ' . $username . '; ID:' . $id;
                echo '<br />';
                //SEND email
                $config = JFactory::getConfig();
                $sender = array(
                    $config->get('mailfrom'),
                    $config->get('fromname')
                );

                $mailer = JFactory::getMailer();
                if (!$mailer) {
                    continue;
                }

                $mailer->setSender($sender);
                $mailer->addRecipient($email);
                //$body = "<p style='color:red'><strong>ERRATA CORRIGE: ci scusiamo per gli invii precedenti, queste sono le uniche credenziali valide.</strong></p>";
                //$body   .= "<br />Caro Associato,<br />da questo momento entra in vigore un nuovo programma gestionale che migliorerà il servizio di prenotazioni e vi darà indicazioni più specifiche riguardo alla vostra posizione (scadenze abbonamento, quota associativa e certificato medico) mantenendo pressochè  invariata la procedura di prenotazione precedente.<br />Avrete a disposizione un ingresso oltre la scadenza dell’abbonamento per il rinnovo, 15 giorni per il rinnovo della quota associativa scaduta e 15 giorni per la presentazione di un certificato medico in corso di validità, dopodiché il sistema bloccherà in automatico l’account fino a successivo aggiornamento della situazione.<br />Sul sito www.crossfitmonza.it dovrete fare login con i dati sottostanti e procedere con il cambio password.<br /><br />Username: ".$username."<br />Password: ".$randpass." (provvisoria)<br /><br />Vi chiediamo in anticipo un po’ di pazienza per eventuali disguidi temporanei e vi preghiamo nel caso di segnalarceli in modo da poter intervenire tempestivamente.<br /><br />Lo staff<br />CrossFit Monza";
                //$body   .= "<br />Caro Associato,<br />di seguito inoltriamo i nuovi accessi come da richiesta: <br />Username: ".$username."<br />Password: ".$randpass." (provvisoria)<br /><br />Vi chiediamo in anticipo un po’ di pazienza per eventuali disguidi temporanei e vi preghiamo nel caso di segnalarceli in modo da poter intervenire tempestivamente.<br /><br />Lo staff<br />CrossFit Monza";
                //$mailer->setSubject('ERRATA CORRIGE: CROSSFIT MONZA - Nuovi accessi');
                //$mailer->setSubject('CROSSFIT MONZA - Reinoltro dei nuovi accessi');
                $link = JURI::root() . "index.php?option=com_users&view=login";
                $body = "<br/>Caro Associato,<br />i tuoi nuovi accessi sono i seguenti:<br /><br />Username:<strong>" . $username . "</strong><br />Password:<strong>" . $randpass . "</strong><br /><br />Clicca sul seguente link per poter effettuare il primo accesso e il cambio password con una a tua scelta<br/><a href='" . $link . "'>" . $link . "</a><br /><br />Lo staff<br />{$mailer->FromName}";
                $mailer->setSubject($mailer->FromName . ' - Link per effettuare primo accesso');

                $mailer->setBody($body);
                $mailer->isHTML(true);
                $send = $mailer->Send();

                if (get_class($mailer->Send()) == 'JException') {
                    JFactory::getApplication()->enqueueMessage("Attenzione: problemi nell'invio della mail", "danger");
                    break;
                } else {
                    $j++;
                }

                unset($mailer);

                $body = "";
            }
        }
        if ($j) {
            JFactory::getApplication()->enqueueMessage("{$j} mail inviate", "success");
        }
        JFactory::getApplication()->redirect("index.php?option=com_crossfit&view=users");
    }

    public function sendEmailToSubscribers() {
        jimport('joomla.access.access');
        jimport('joomla.user.helper');
        $db = JFactory::getDbo();

        $groups = JAccess::getUsersByGroup(12); //12 - Test Email da sostituire con Crossfit iscritti
        $j = 1;
        foreach ($groups as $id) {
            $usr = JFactory::getUser($id);
            if ($usr->email == 'stefania@crossfitmonza.it') {
                continue;
            }

            $username = $usr->username;
            $email = $usr->email;

            //da riabilitare per meda
            //$randpass       = JUserHelper::genRandomPassword(8);
            $randpass = $username;

            $salt = JUserHelper::genRandomPassword(32);
            $crypt = JUserHelper::getCryptedPassword($randpass, $salt);
            $password = "$crypt:$salt";

            $object = new stdClass();

            // Must be a valid primary key value.
            $object->id = $id;
            $object->password = $password;
            $object->requireReset = 1; //imposto la richiesta di cambio psw al primo accesso
            $result = $db->updateObject('#__users', $object, 'id');
            if ($result !== true) {
                echo 'Error to saving data for user: ' . $username . ' id:' . $id;
            } else {
                echo 'Data saved for user: ' . $username . '; ID:' . $id;
                echo '<br />';
                //SEND email
                $config = JFactory::getConfig();
                $sender = array(
                    $config->get('mailfrom'),
                    $config->get('fromname')
                );

                $mailer = JFactory::getMailer();

                $mailer->setSender($sender);
                $mailer->addRecipient($email);
                //$body = "<p style='color:red'><strong>ERRATA CORRIGE: ci scusiamo per gli invii precedenti, queste sono le uniche credenziali valide.</strong></p>";
                //$body   .= "<br />Caro Associato,<br />da questo momento entra in vigore un nuovo programma gestionale che migliorerà il servizio di prenotazioni e vi darà indicazioni più specifiche riguardo alla vostra posizione (scadenze abbonamento, quota associativa e certificato medico) mantenendo pressochè  invariata la procedura di prenotazione precedente.<br />Avrete a disposizione un ingresso oltre la scadenza dell’abbonamento per il rinnovo, 15 giorni per il rinnovo della quota associativa scaduta e 15 giorni per la presentazione di un certificato medico in corso di validità, dopodiché il sistema bloccherà in automatico l’account fino a successivo aggiornamento della situazione.<br />Sul sito www.crossfitmonza.it dovrete fare login con i dati sottostanti e procedere con il cambio password.<br /><br />Username: ".$username."<br />Password: ".$randpass." (provvisoria)<br /><br />Vi chiediamo in anticipo un po’ di pazienza per eventuali disguidi temporanei e vi preghiamo nel caso di segnalarceli in modo da poter intervenire tempestivamente.<br /><br />Lo staff<br />CrossFit Monza";
                //$body   .= "<br />Caro Associato,<br />di seguito inoltriamo i nuovi accessi come da richiesta: <br />Username: ".$username."<br />Password: ".$randpass." (provvisoria)<br /><br />Vi chiediamo in anticipo un po’ di pazienza per eventuali disguidi temporanei e vi preghiamo nel caso di segnalarceli in modo da poter intervenire tempestivamente.<br /><br />Lo staff<br />CrossFit Monza";
                //$mailer->setSubject('ERRATA CORRIGE: CROSSFIT MONZA - Nuovi accessi');
                //$mailer->setSubject('CROSSFIT MONZA - Reinoltro dei nuovi accessi');
                $link = JURI::root() . "index.php?option=com_users&view=login";
                $body = "<br/>Caro Associato,<br />i tuoi nuovi accessi sono i seguenti:<br /><br />Username:<strong>" . $username . "</strong><br />Password:<strong>" . $randpass . "</strong><br /><br />Clicca sul seguente link per poter effettuare il primo accesso e il cambio password con una a tua scelta<br/><a href='" . $link . "'>" . $link . "</a><br /><br />Lo staff<br />{$mailer->FromName}";
                $mailer->setSubject($mailer->FromName . ' - Link per effettuare primo accesso');

                $mailer->setBody($body);
                $mailer->isHTML(true);
                $send = $mailer->Send();
                if ($send !== true) {
                    echo 'Error sending email: ' . $send->__toString() . '#UserID' . $id;
                } else {
                    echo '#' . $j . ' - Mail sent #UserID' . $id . " #mail " . $email;
                }
                echo '<br /><br />';

                unset($mailer);

                $body = "";
                $j++;
            } //end if user!=880 (stefania)
        }
    }

}
